@@ -35,6 +35,18 @@ $ python setup.py help
      libraries=["milter","smutil","resolv"]
 
  * $Log: miltermodule.c,v $
+ * Revision 1.27  2009/07/28 21:45:54  customdesigned
+ * Add getversion() to return runtime version.
+ *
+ * Revision 1.26  2009/07/28 21:08:20  customdesigned
+ * Increment del count.
+ *
+ * Revision 1.25  2009/07/28 20:58:55  customdesigned
+ * getdiag method
+ *
+ * Revision 1.24  2009/06/09 01:54:44  customdesigned
+ * Forgot to initialize optional parameter.
+ *
  * Revision 1.23  2009/05/29 20:44:58  customdesigned
  * Typo SMFIP_NO constants.
  *
@@ -278,6 +290,12 @@ staticforward struct smfiDesc description; /* forward declaration */
 static PyObject *MilterError;
 /* The interpreter instance that called milter.main */
 static PyInterpreterState *interp;
+typedef struct {
+  unsigned int contextNew;
+  unsigned int contextDel;
+} milter_Diag;
+
+static milter_Diag diag;
 
 staticforward PyTypeObject milter_ContextType;
 
@@ -316,6 +334,7 @@ _get_context(SMFICTX *ctx) {
       PyThreadState_Delete(t);
       return NULL;
     }
+    ++diag.contextNew;
     self->t = t;
     self->ctx = ctx;
     Py_INCREF(Py_None);
@@ -354,6 +373,7 @@ milter_Context_dealloc(PyObject *s) {
   }
   Py_DECREF(self->priv);
   PyObject_DEL(self);
+  ++diag.contextDel;
 }
 
 /* Throw an exception if an smfi call failed, otherwise return PyNone. */
@@ -1066,6 +1086,30 @@ milter_stop(PyObject *self, PyObject *args) {
   return _thread_return(t,smfi_stop(), "cannot stop");
 }
 
+static char milter_getdiag__doc__[] =
+"getdiag() -> tuple\n\
+Return a tuple of diagnostic data.  The first two items are context new\n\
+count and context del count.  The rest are yet to be defined.";
+static PyObject *
+milter_getdiag(PyObject *self, PyObject *args) {
+  if (!PyArg_ParseTuple(args, ":getdiag")) return NULL;
+  return Py_BuildValue("(kk)", diag.contextNew,diag.contextDel);
+}
+
+static char milter_getversion__doc__[] =
+"getversion() -> tuple\n\
+Return runtime libmilter version as a tuple of major,minor,patchlevel.";
+static PyObject *
+milter_getversion(PyObject *self, PyObject *args) {
+  unsigned int major, minor, patch;
+  if (!PyArg_ParseTuple(args, ":getversion")) return NULL;
+  if (smfi_version(&major,&minor,&patch) != MI_SUCCESS) {
+    PyErr_SetString(MilterError, "smfi_version failed");
+    return NULL;
+  }
+  return Py_BuildValue("(kkk)", major,minor,patch);
+}
+
 static char milter_getsymval__doc__[] =
 "getsymval(String) -> String\n\
 Returns a symbol's value.  Context-dependent, and unclear from the dox.";
@@ -1191,7 +1235,7 @@ This function can only be called from the EOM callback.";
 static PyObject *
 milter_chgfrom(PyObject *self, PyObject *args) {
   char *sender;
-  char *params;
+  char *params = NULL;
   SMFICTX *ctx;
   PyThreadState *t;
   
@@ -1478,6 +1522,8 @@ static PyMethodDef milter_methods[] = {
    { "setbacklog",           milter_setbacklog,           METH_VARARGS, milter_setbacklog__doc__},
    { "setconn",              milter_setconn,              METH_VARARGS, milter_setconn__doc__},
    { "stop",                 milter_stop,                 METH_VARARGS, milter_stop__doc__},
+   { "getdiag",              milter_getdiag,              METH_VARARGS, milter_getdiag__doc__},
+   { "getversion",           milter_getversion,           METH_VARARGS, milter_getversion__doc__},
    { NULL, NULL }
 };
 
