@@ -1,5 +1,4 @@
 import unittest
-import testbms
 import testmime
 import testsample
 import testutils
@@ -7,7 +6,6 @@ import os
 
 def suite(): 
   s = unittest.TestSuite()
-  s.addTest(testbms.suite())
   s.addTest(testmime.suite())
   s.addTest(testsample.suite())
   s.addTest(testutils.suite())
